const signale = require('signale');
const semver = require('semver');
const path = require('path')
const lodash = require('lodash');
const client = require('./core');
const config = require('../bin/config');
const debug = require('debug')(`dingtalk-cli-pro:cli`)
const updater = require('update-notifier');
const chalk = require('chalk');
const pkg = require('../package.json');
const spawn = require('./util/spawn-command');
const cwd = process.cwd();

// 检查版本，每隔个小时
updater({ pkg, updateCheckInterval: config.UPDATE_CHECK_INTERVAL} ).notify({ defer: true });
// Node version check
const nodeVersion = process.versions.node;
if (semver.satisfies(nodeVersion, '< 8.9')) {
  signale.error(`Node version must >= 8.9, but got ${nodeVersion}`);
  process.exit(1);
}


// execute system plugin: install, list, publish, dev
client.executeSystemPlugin();


let clientConfig = lodash.merge({ pluginPath: ''}, pkg[config.brandName])

if (client.fs.exists(path.join(cwd, `.${config.brandName}rc.js`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `.${config.brandName}rc.js`)));
} else if (client.fs.exists(path.join(cwd, `${config.brandName}rc.js`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `${config.brandName}rc.js`)));
} else if (client.fs.readJSON(path.join(cwd, `.${config.brandName}rc`))) {
  lodash.merge(clientConfig, client.fs.readJSON(path.join(cwd, `.${config.brandName}rc`)));
}

// loader install plugin from dingtalk-cli-pro node_modules for system folder
if (config.env === 'prod') {
  client.loaderInstalledPlugin(path.resolve(config.npmRoot, `./${config.npmName}/node_modules`));
} 

// loader installed plugin from system folder
client.loaderInstalledPlugin(config.npmRoot);
// loader point plugins from config

if (clientConfig.plugins && clientConfig.plugins.length && lodash.isArray(clientConfig.plugins)) {
  client.loaderConfigPluginFiles(clientConfig.plugins, cwd);
}



// parse argv 
client.program
.version(pkg.version)
.on('command:*', () => {
  console.log(`${client.randomEmoji()}  Invalid command: ${chalk.red(client.program.args.join(' '))} \n See --help for a list of available commands.`);
  process.exit(1);
})
.parse(process.argv);

