
const chalk = require('chalk');
const path = require('path');
const config = require('../../bin/config');
const util = require('../util.js');
const lodash = require('lodash');
const spawn = require('../util/spawn-command')
const debug = require('debug')('dingtalk-cli-pro:build')


module.exports = function(client) {
  client
  .registryCommand('build')
  .alias('b')
  .option('-t, --terser', 'Minify Building Code')
  .description(chalk.yellow('Build App On Local'))
  .action(async (cmd) => {
    const abcJson = util.getAbcJson(path.resolve(process.cwd(), './abc.json'));
    const plugin = (abcJson.plugin || {});
    const noLocalIdentName = (abcJson.config || {}).noLocalIdentName || [];
    const pluginName = plugin.name;

    if (lodash.isEmpty(plugin) || !lodash.isArray(plugin.cmd) ) {
      this.log.error(`abc json plugin property is null`, plugin);
      process.exit(1)
    }

    if (util.isPluginName(pluginName)) {

      let command = noLocalIdentName.length ? plugin.cmd.concat(['-n', noLocalIdentName.join('|')]) :  plugin.cmd;
      command = command.map(name => {
        if (name === 'dev') {
          return 'prod'
        }
        return name
      });


      if (!cmd.terser) {
        command.push('-s')
      }
    
      debug('build cmd: %o', command);
      spawn.spawnCommandSync(config.clientName, command)

    } else {
      this.log.error(`plugin name ${pluginName} is illegal, example: ${brandName}-plugin-xx, ${WHITE_LIST.map(prefix => prefix + '/' + brandName + '-plugin-xx').join(', ')}`)
    }    
  });
}