const getLastVersion = require('latest-version');
const boxen = require('boxen');
const chalk = require('chalk');
const compareVersions = require('compare-versions');
const spawn = require('./util/spawn-command');
const config = require('../bin/config');
const path = require('path');

const getBoxenListString = (list) => {
  const str = list.filter(item => item.isUpdate).map(item => {
    return `${chalk.red(item.name)}: ${chalk.gray(item.preVersion || item.version)} -> ${chalk.yellow(item.version)}`  
  })
  return boxenStr = `
Packages Last Version List:

${str.join('\n')}
`
}

const updateNotify = async (pkgList, show = false) => {
  const list = pkgList;
  let isUpdate = show;
  for (let i = 0; i < pkgList.length; i++) {
    const pkg = pkgList[i];
    const lastVersion = await getLastVersion(pkg.name);
    if (compareVersions.compare(lastVersion, pkg.version, '>')) {
      list[i] = {
        version: lastVersion,
        preVersion: pkg.version,
        name: pkg.name,
        isUpdate: true
      }
      isUpdate = true;
    }
  }
  

  if (isUpdate) {
    console.log(boxen(
      getBoxenListString(list),  
      {
      borderColor: 'blue',
      padding: {
        left: 2,
        right: 2
      }
    })) 
  }

  return {
    list,
    isUpdate
  };
}

const updateInstall = async (pkgList) => {
  const { list, isUpdate } = await updateNotify(pkgList);
  list.forEach(pkg => {
    if (pkg.isUpdate) {
      spawn.spawnCommandSync(config.npmClient || 'tnpm', ['install', `${pkg.name}@${pkg.version}`], {
        cwd: path.resolve(__dirname, '../../../') // target install to node_module: lib -> dingtalk-cli-pro -> node_module
      })
    }
  })

  if (isUpdate) {
    console.log(boxen(
      `Checking and Updating ${chalk.hex('#fd6dc0')(pkgList.map(item => item.name).join(','))} Finishing`,
      {
      borderColor: '#455a66',
      padding: {
        left: 2,
        right: 2
      }
    }));
  }

  
  return {
    list,
    isUpdate
  }
}

module.exports = {
  updateNotify,
  updateInstall
}