const path = require('path');
const fs = require('fs')
const shelljs = require('shelljs');
const debug = require('debug')('debug:util')
const readPkgUp = require('read-pkg-up');
const log = require('./util/log');
const boxen = require('boxen');

const config = require('../bin/config');
const WHITE_LIST = config.WHITE_LIST;
const PLUGIN_REGEXP = new RegExp(config.PLUGIN_REGEXP);

const getPluginNameAndPath = (root) => {
  const list = [];
  let filePath = '';
  const pushPlugin = (name, filePath) => {
    if (isPluginName(name) && fs.existsSync(filePath)) {
      list.push({
        name, 
        path: filePath
      });
    }
  } 

  fs.readdirSync(root).forEach(name => {
    if (WHITE_LIST.indexOf(name) === -1) {
      filePath = path.join(root, name, './index.js');
      pushPlugin(name, filePath);
    } else {
      const depthRoot = path.join(root, name);
      fs.readdirSync(depthRoot).forEach(subName => {
        filePath = path.join(depthRoot, subName, './index.js');
        pushPlugin([name, subName].join('/'), filePath);
      })
    }
  })
  
  return list;
}

const isPluginName = (name = '') => {
  return PLUGIN_REGEXP.test(name)
}

const getGitUserInfo = () => {
  const username = shelljs.exec('git config --get user.name', {
    silent: true
  }).output.trim();
  const email = shelljs.exec('git config --get user.email', {
    silent: true
  }).output.trim();

  return {
    username,
    email
  }
}


const getAbcJson = (path) => {
  let abc = {};
  try {
    abc = fs.existsSync(path) ? JSON.parse(fs.readFileSync(path, 'utf8')) : {};
  } catch(err) {
    log.error(err);
    process.exit(1);
  } 

  return abc;
  
}

const getPackageInfo = async (cwdPath) => {
  try {
    return await readPkgUp({
      cwd: cwdPath
    })
  } catch(err) {
    return null;
  }
  
}

const publishDirBoxed = (publishDir) => {
  console.log(boxen(
    `
    Your Publish Page Address:
    
    ${publishDir}
    `,  
    {
    borderColor: 'blue',
    padding: {
      left: 2,
      right: 2
    }
  })) 
}

const getNpmRoot = () => {
  const npmRoot = shelljs.exec('npm root -g', {
    silent: true
  }).stdout;

 return npmRoot.trim();
}


module.exports = {
  isPluginName,
  getPluginNameAndPath,
  getGitUserInfo,
  getAbcJson,
  getPackageInfo,
  publishDirBoxed,
  getNpmRoot
}