'use strict';
const path = require('path');
const chalk = require('chalk');
const { spawnCommand } = require('./spawn-command');
const debug = require('debug')('uitl:install');
/**
 * @mixin
 * @alias actions/install
 */
const install = module.exports;

install.runInstall = function (installer, spawnOptions, args) {
  return new Promise((resolve, reject) => {
    spawnCommand(installer, args, spawnOptions)
      .on('error', err => {
        reject(err);
      })
      .on('exit', () => {
        console.log(chalk.blue('🌈 Install packages finish... \n'));
        resolve();
      });
  });
};


install.npmInstall = function (dir = '') {
  debug('npmInstall %s', dir);
  return install.runInstall('npm', {
    cwd: path.join(process.cwd(), dir)
  }, ['install']);
};

install.tnpmInstall = function (dir = '') {
  debug('tnpmInstall %s', dir);
  
  return install.runInstall('tnpm', {
    cwd: path.join(process.cwd(), dir)
  }, ['install']);
};

install.yarnInstall = function (dir = '') {
  debug('yarnInstall %s', dir);
  return install.runInstall('yarn', {
    cwd: path.join(process.cwd(), dir)
  }, ['--ignore-engines']);
};

install.install = async function(cmd, dir = '') {
  if (cmd === 'tnpm') {
    await this.tnpmInstall(dir);
  } else if (cmd === 'npm') {
    await this.npmInstall(dir);
  } else {
    await this.yarnInstall(dir);
  }
}
